pub struct EventFanout { /* private fields */ }Expand description
Broadcasts a single event stream to multiple subscribers.
Implementations
Sourceimpl EventFanout
impl EventFanout
Sourcepub fn new(event_stream: BoxEventStream<Event>, buffer: usize) -> Self
pub fn new(event_stream: BoxEventStream<Event>, buffer: usize) -> Self
Spawn a background task that forwards events into a broadcast channel.
Sourcepub fn subscribe(&self) -> BoxEventStream<Event>
pub fn subscribe(&self) -> BoxEventStream<Event>
Create a new stream receiver over the broadcast channel.