pub struct Tracer { /* private fields */ }Expand description
Owns the telemetry lifecycle for a specific event stream.
Implementations
Sourceimpl Tracer
impl Tracer
pub fn new( provider: Arc<dyn TelemetryProvider>, event_stream: BoxEventStream<Event>, ) -> Self
pub fn from_direct<T>( provider: Arc<dyn TelemetryProvider>, handle: &mut DirectAgentHandle<T>, ) -> Self
pub async fn from_environment( provider: Arc<dyn TelemetryProvider>, env: &mut Environment, runtime_id: Option<RuntimeID>, ) -> Result<Self, TelemetryError>
pub fn with_shutdown_grace(self, duration: Duration) -> Self
Sourcepub fn start(&mut self) -> Result<(), TelemetryError>
pub fn start(&mut self) -> Result<(), TelemetryError>
Start exporting spans and metrics from the configured event stream.
Sourcepub async fn shutdown(&mut self) -> Result<(), TelemetryError>
pub async fn shutdown(&mut self) -> Result<(), TelemetryError>
Flush and shut down exporters.